@@ -25,10 +25,12 @@ c 2014-05-02 RBS: Split the real and integer declarations to reflect
 c                 called and local variables.
 c 2015-06-23 RBS: Declared time_flag, half_step, whole_step internal to
 c                 function to eliminate compiler warnings
+c 2018-02-22 RBS: Added a new output parameter in the MITL model, closs,
+c                 needed to output closs from rstmitl.
 c ----------------------------------------------------------------------
 c
 c value is the returned value of the requested variable.
-c type is variable requested.
+c vtype is variable requested.
 c branch, block and node specify its location in the circuit.
 c node is the first block node, lastnode is the lastblock node.
 c blktype is type of circuit block it is for.
@@ -382,6 +384,8 @@ c MITL Model parameters available for plotting
 c
       else if (vtype .eq. ip_aloss) then
         value = pin(10,ipinblk,branch) 
+      else if (vtype .eq. ip_closs) then
+        value = pin(11,ipinblk,branch)
 c
 c ---------------------------------------------------------------------
 c
