@@ -35,6 +35,9 @@ c 2017-12-16 RBS: Increased the length of the lblout to 16 from 12
 c 2017-12-16 RBS: Increased the number of data col from 100 to 120
 c 2018-01-31 RBS: Increase the number of data col from 120 to 150
 c 2019-01-16 RBS: Increase the number of data col from 150 to 200
+c 2019-01-27 RBS: Added a scale_out multiplier to the print outdata loop
+c 2019-01-28 RBS: Increased the length of the lblout to 22 from 16
+c 2019-04-05 RBS: Changed output file name
 c
 c-------Include Files---------------------------------------------------
 c
@@ -94,14 +97,14 @@ c
 c     strip off the text file extension
 c
       call strip_name (ufofile(i_1st:i_last),tempfile,lentemp)
-      filename = tempfile(1:lentemp)//'.ufo'
+      filename = tempfile(1:lentemp)//'_d.txt'
       open (unit=ufo_unit, file=filename, status='unknown')
 c
 c
 C   write out the observer names out as data column labels
 C
-      write (ufo_unit, '(A10,1x,200(A16))')
-     &      'Time (s)  ',(lblout(indices(j))(1:16), j=1,numufo)
+      write (ufo_unit, '(A10,1x,200(A22))')
+     &      'Time (s)  ',(lblout(indices(j))(1:22), j=1,numufo)
 C
 c      
 c  Process UFO output requests
@@ -113,7 +116,7 @@ c
       iunit   = outunit
       call open_outfile (iunit, fflag, ierr)
 c
-c       Get the value of time t1/2 and first data value at time 0.0
+c  Get the value of time t1/2 and first data value at time 0.0
 c
       newrec = 1
       ipntcnt = 1
@@ -132,6 +135,8 @@ c
       enddo
 c
 c Get values for the rest of the simulation
+c
+c first skip unwanted data
 c
       newrec = 1
       call read_outfile (iunit, newrec, time_flag, indices(1),
@@ -147,8 +152,9 @@ c
             timeout(ipntcnt,1) = tmptime
             outdata(ipntcnt,1) = tmpval
             newrec = 0
+c
 c change i here to j for clarity
-c scale temp val by inputted scale factor
+c
             do i = 2, numufo
                call read_outfile(iunit, newrec, time_flag, indices(i),
      +                           ibufsize, tmptime, tmpval, ierr)
@@ -178,7 +184,7 @@ c Set the number of points to be printed in the first line of the group
 c of values. Writes the output data array.
 c
         write (ufo_unit, '(201(1pe12.5,2x))')
-     &        timeout(i,1),(outdata(i,j), j=1,numufo)
+     &        timeout(i,1),(outdata(i,j)*scale_out(j), j=1,numufo)
 c
       end do        !end of loop over time points
 c
