@@ -10,7 +10,7 @@ c
 c
 c Define passed variables
 c
-      character*80 name
+      character*(*) name
       real diel
       integer flag
 c
