@@ -69,7 +69,7 @@ c
 
 c ======================================================
 c Initializations
-c Write a banner page with SCREAMER title and name.
+c Write a banner page with SCREAMER title and name in log file.
       call banner (page1)
 
 c Read the general run parameters of the simulation
@@ -88,12 +88,17 @@ c ======================================================
 c Read and process circuit elements
 c  
   305 continue
-c Read in one line and strip the blanks and commas.
+
+c Read in one line of the input deck and strip the blanks and commas.
+
       call get_next_line
      &     (currline, currline_lc, field, nlines, eofflg, max_fields)
         if (eofflg .eq. err) go to 1000
         keyword = field(1)(1:keyword_len)
-c Read element according to keyword
+
+c Read if the keyword is a branch or an electrical element
+c If neither status remains 0 else status = 10 = k_found
+c
       call readscreamerelements(status)
         if (status .eq. k_found) goto 305
 c
@@ -101,19 +106,26 @@ c status 305 indicates a bad command
 c
         if (status .eq. 305) goto 305
 c
-c Status 1000 indicates that end of file reached
+c Status 1000 indicates that end of file reached,
 c
         if (status .eq. 1000) goto 1000
-c the keyword was for an output
+c
+c status was neither k_found, 305, or 1000. Could be a blank line or
+c a comment, an output requeset, etc.
+c
+c Get the output information if keyword was for an output request
+c numout initialized to 0 in readscrinit.f. Every good output request
+c increments numout in rdscrelem.f
 c      print '(i8)', numout
-c
-c status was neither k_found, 305, or 1000 Could be a blank line or
-c a comment, etc.
-c
+
       call readscreameroutputs(status)
+c Even if there was a bad line get next line
         if (status .eq.  305) goto 305
+c Here status equals 1000 only if the numouts has exceed maxout
         if (status .eq. 1000) goto 1000
+c If you got here
       goto 305
+
 c ======================================================
  1000 continue
 c
@@ -134,7 +146,7 @@ c counters and the block counter array, and return to calling program.
 c Otherwise, tell read errors encountered and stop.
 c
       if (numerr .eq. 0) then
-        write(6,'(A)') ' Input file read with no errors.'
+        write(6,'(A/)') '   Input file read with no errors.'
         status=0
       else
         write(6,'(A)')
