@@ -25,6 +25,8 @@ c                 the actual subroutines to remove compiler warnings
 c 2015-06-23 RBS: lblout_temp length increased to 26 to agree with
 c                 labelout
 c 2016-04-01 RBS: xlblout parameter changed to 'Time (s)'
+c 2019-01-27 RBS: Add real variable scale_out declared to
+c                 the same array size as the output data variables
 c
 c file zdemout.h
 c ***** The common block for plotting *****
@@ -38,6 +40,7 @@ c
       real
      & saveout1(maxout), saveout2(maxout),
      & saveout3(maxout), saveout4(maxout),
+     & scale_out(maxout),
      & tbegout(maxout), tendout(maxout),
      & val1(maxout), val2(maxout),
      & yminout(maxout), ymaxout(maxout)
@@ -64,6 +67,7 @@ c
       common /outstuff/
      & saveout1, saveout2,
      & saveout3, saveout4,
+     & scale_out,
      & tbegout, tendout,
      & val1, val2,
      & yminout, ymaxout,
